@@ -1,4 +1,11 @@
-## ----fig.width=7, fig.retina=2, fig.align='left', fig.cap="Rectangular Cartogram of the U.S. election 2004; The area corresponds to the number of electors (color indicates the party red: democrats / blue: Republican; the color intensity ~ outcome of the vote.). The graphic was computed by using the original implementation of the construction heuristic RecMap MP2 introduced in [@recmap].", echo=FALSE, warning=FALSE, comment="ccc", error=FALSE, message=FALSE----
+## ----eval = TRUE, echo = FALSE--------------------------------------
+options(prompt = "R> ",
+  continue = "+  ",
+  width = 70,
+  useFancyQuotes = FALSE,
+  warn = -1)
+
+## ----fig.width=7, fig.height=3.5, fig.retina=2, fig.align='left', fig.cap="Rectangular Cartogram of the U.S. election 2004; The area corresponds to the number of electors (color indicates the party red: democrats / blue: Republican; the color intensity ~ outcome of the vote.). The graphic was computed by using the original implementation of the construction heuristic RecMap MP2 introduced in [@recmap].", echo=FALSE, warning=FALSE, comment="ccc", error=FALSE, message=FALSE----
 
 library(recmap)
 op <- par(mar = c(0,0,0,0), bg = 'black')
@@ -6,13 +13,13 @@ recmap:::.draw_recmap_us_state_ev()
 par(op)
 # detach("package:recmap", unload=TRUE)
 
-## ----eval=TRUE, echo=TRUE, message=TRUE----------------------------------
+## ----eval=TRUE, echo=TRUE, message=TRUE-----------------------------
 library(recmap)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  help(package="recmap")
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------
 usa <- data.frame(x = state.center$x, 
     y = state.center$y, 
     # make the rectangles overlapping by correcting lines of longitude distance
@@ -21,13 +28,13 @@ usa <- data.frame(x = state.center$x,
     z = sqrt(state.area),
     name = state.name)
 
-## ----fig.width=7, fig.height=3-------------------------------------------
+## ----fig.width=7, fig.height=3--------------------------------------
 library(recmap)
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
 plot.recmap(M <- usa[!usa$name %in% c("Hawaii", "Alaska"), ],  
             col.text = 'black', lwd=2)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------
 Cartogram <- recmap(Map <- usa[!usa$name %in% c("Hawaii", "Alaska"), ])
 head(Cartogram)
 
@@ -37,17 +44,17 @@ smp <- c(29, 22, 30, 3, 17, 8, 9, 41, 18, 15, 38, 35, 21, 23, 19, 6, 31, 32, 20,
         28, 48, 4, 13, 14, 42, 37, 5, 16, 36 , 43, 25, 33, 12, 7, 39, 44, 2, 47,
         45, 46, 24, 10, 1,11 ,40 ,26 ,27 ,34)
 
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
 plot(Cartogram.Population <- recmap(M[smp, ]), 
             col.text = 'black', lwd=2)
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------
 summary.recmap(M)
 summary(Cartogram.Population)
 
 ## ----fig.width=8, fig.height=4, fig.align='left', fig.cap="Area ~ population estimate as of July 1, 1975;", warning=FALSE----
 
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
 usa$z <- state.x77[, 'Population']
 M <- usa[!usa$name %in% c("Hawaii", "Alaska"), ]
 plot(Cartogram.Population <- recmap(M[order(M$x),]), 
@@ -60,26 +67,34 @@ plot(Cartogram.Population <- recmap(M[order(M$x),]),
 smp <- c(20,47,4,40,9,6,32,33,3,10,34,22,2,28,15,12,39,7,42,45,19,13,43,30,24,
          25,11,17,37,41,26,29,21,35,8,36,14,16,31,48,46,38,23,18,1,5,44,27)
 
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
 plot(Cartogram.Population <- recmap(M[smp,]), col.text = 'black', lwd = 2)
 
 ## ----fig.width=8, fig.height=4, fig.align='left', fig.cap="Area ~ capita income (1974);"----
 usa$z <- state.x77[, 'Income']
 M <- usa[!usa$name %in% c("Hawaii", "Alaska"), ]
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
 plot(Cartogram.Income <- recmap(M[order(M$x),]), col.text = 'black', lwd = 2)
 
-## ----fig.width=8, fig.height=4, fig.align='left', fig.cap="Area ~ mean number of days with minimum temperature below freezing (1931–1960) in capital or large city;"----
+## ----fig.width=8, fig.height=4, fig.align='left', warnings = FALSE, fig.cap="Area ~ mean number of days with minimum temperature below freezing (1931–1960) in capital or large city;"----
 usa$z <- state.x77[, 'Frost'] 
 M <- usa[!usa$name %in% c("Hawaii", "Alaska"), ]
-op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0))
-plot(Cartogram.Income <- recmap(M[order(M$x),]), 
+op <- par(mfrow = c(1 ,1), mar = c(0, 0, 0, 0), bg = NA)
+Frost <- recmapGA(M, seed = 1)
+plot(Frost$Cartogram, 
             col.text = 'black', lwd = 2)
 
-## ----eval=FALSE----------------------------------------------------------
+## -------------------------------------------------------------------
+summary(Frost)
+
+## ----eval=FALSE-----------------------------------------------------
+#  # Requires to install the suggested packages
+#  # install.packages(c('colorspace', 'maps', 'noncensus', 'shiny'))
+#  
 #  library(shiny)
-#  recmap_state.x77 <- system.file("shiny-examples", "state.x77", package = "recmap")
-#  shiny::runApp(recmap_state.x77, display.mode = "normal")
+#  
+#  recmap_shiny <- system.file("shiny-examples", package = "recmap")
+#  shiny::runApp(recmap_shiny, display.mode = "normal")
 
 ## ----fig.width=7, fig.height=2.5, fig.align='center', fig.retina=2, fig.cap="checkerboard fun - input, area of black regions have to be four times as big as white regions (left); solution found by a greedy random algorithm (middle); solution found by genetic algorithm (right)", fig.align='left'----
 op <- par(mar = c(0, 0, 0, 0), mfrow = c(1, 3), bg = 'white')
@@ -107,6 +122,6 @@ plot(Cartogram.checkerboard8x8.ga <- recmap(checkerboard8x8[index.ga,]),
             col = c('white','white','white','black')[Cartogram.checkerboard8x8.ga$z])
 
 
-## ------------------------------------------------------------------------
+## -------------------------------------------------------------------
 sessionInfo()
 
